==> haskell-zip-archive-0.3.0.5-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-zip-archive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: zip-archive
version: 0.3.0.5
id: zip-archive-0.3.0.5-4R8dq2PHAV4JpIvEapAb0Q
key: zip-archive-0.3.0.5-4R8dq2PHAV4JpIvEapAb0Q
license: BSD3
maintainer: jgm@berkeley.edu
homepage: http://github.com/jgm/zip-archive
synopsis: Library for creating and modifying zip archives.
description:
    The zip-archive library provides functions for creating, modifying,
    and extracting files from zip archives.
category: Codec
author: John MacFarlane
exposed: True
exposed-modules:
    Codec.Archive.Zip
abi: bc207f2ef53292e5e29005fb2941238c
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/zip-archive-0.3.0.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/zip-archive-0.3.0.5
data-dir: /usr/share/i386-linux-ghc-8.0.1/zip-archive-0.3.0.5
hs-libraries: HSzip-archive-0.3.0.5-4R8dq2PHAV4JpIvEapAb0Q
depends:
    array-0.5.1.1 base-4.9.0.0 binary-0.8.3.0 bytestring-0.10.8.1
    containers-0.5.7.1 digest-0.0.1.2-J37LLBONunyDWQLOlAJhTF
    directory-1.2.6.2 filepath-1.4.1.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    old-time-1.1.0.3-IcvdkJUsE9M8t3io8peAEp pretty-1.1.3.3
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1 unix-2.7.2.0
    zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
haddock-interfaces: /usr/share/doc/haskell-zip-archive/html/zip-archive.haddock
haddock-html: /usr/share/doc/haskell-zip-archive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-zip-archive-0.3.0.6-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-zip-archive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: zip-archive
version: 0.3.0.6
id: zip-archive-0.3.0.6-Ig0t72Nj5zm5vunOYcd6Nx
key: zip-archive-0.3.0.6-Ig0t72Nj5zm5vunOYcd6Nx
license: BSD3
maintainer: jgm@berkeley.edu
homepage: http://github.com/jgm/zip-archive
synopsis: Library for creating and modifying zip archives.
description:
    The zip-archive library provides functions for creating, modifying,
    and extracting files from zip archives.
category: Codec
author: John MacFarlane
exposed: True
exposed-modules:
    Codec.Archive.Zip
abi: 91f8a336b6a0f51c72996ed5352fa63a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/zip-archive-0.3.0.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/zip-archive-0.3.0.6
data-dir: /usr/share/i386-linux-ghc-8.0.1/zip-archive-0.3.0.6
hs-libraries: HSzip-archive-0.3.0.6-Ig0t72Nj5zm5vunOYcd6Nx
depends:
    array-0.5.1.1 base-4.9.0.0 binary-0.8.3.0 bytestring-0.10.8.1
    containers-0.5.7.1 digest-0.0.1.2-J37LLBONunyDWQLOlAJhTF
    directory-1.2.6.2 filepath-1.4.1.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    old-time-1.1.0.3-IcvdkJUsE9M8t3io8peAEp pretty-1.1.3.3
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1 unix-2.7.2.0
    zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
haddock-interfaces: /usr/share/doc/haskell-zip-archive/html/zip-archive.haddock
haddock-html: /usr/share/doc/haskell-zip-archive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
